@@ -20,6 +20,8 @@ function _aws_cdk_assertions_Capture(p) {
 }
 function _aws_cdk_assertions_Template(p) {
 }
+function _aws_cdk_assertions_Annotations(p) {
+}
 function _aws_cdk_assertions_MatchResult(p) {
 }
 function _aws_cdk_assertions_Match(p) {
@@ -39,5 +41,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_assertions_MatchFailure, _aws_cdk_assertions_MatchCapture, _aws_cdk_assertions_Matcher, _aws_cdk_assertions_Capture, _aws_cdk_assertions_Template, _aws_cdk_assertions_MatchResult, _aws_cdk_assertions_Match };
+module.exports = { print, _aws_cdk_assertions_MatchFailure, _aws_cdk_assertions_MatchCapture, _aws_cdk_assertions_Matcher, _aws_cdk_assertions_Capture, _aws_cdk_assertions_Template, _aws_cdk_assertions_Annotations, _aws_cdk_assertions_MatchResult, _aws_cdk_assertions_Match };
 module.exports.DeprecationError = DeprecationError;
